# coding=utf-8
import logging
import traceback

import timeout_decorator
from django.conf import settings
from django_cron import CronJobBase, Schedule

from exporter import Exporter
from web.models.constants import CRON_JOB_TIMEOUT
from ..smash_email import EmailSender

logger = logging.getLogger(__name__)


class ExporterCronJob(CronJobBase):
    RUN_AT_TIMES = getattr(settings, "EXPORT_RUN_AT", ['23:55'])
    schedule = Schedule(run_at_times=RUN_AT_TIMES)
    code = 'web.import_daily_job'  # a unique code

    @timeout_decorator.timeout(CRON_JOB_TIMEOUT)
    def do(self):
        email_title = "Daily export"
        email_recipients = getattr(settings, "DEFAULT_FROM_EMAIL", None)

        filename = getattr(settings, "DAILY_EXPORT_FILE", None)

        if filename is None:
            logger.info("Exporting subjects skipped. File not defined ")
            return "export file not defined"
        logger.info("Exporting subjects from file: " + filename)
        try:
            exporter = Exporter(settings.DAILY_EXPORT_FILE)
            exporter.execute()
            email_body = exporter.get_summary()
            EmailSender().send_email(email_title,
                                     "<h3>Data was successfully exported to file: " + filename + "</h3>" + email_body,
                                     email_recipients)
            return "export is successful"

        except:
            tb = traceback.format_exc()
            EmailSender().send_email(email_title,
                                     "<h3><font color='red'>There was a problem with exporting data to file: " + filename + "</font></h3><pre>" + tb + "</pre>",
                                     email_recipients)
            return "export crashed"
