# coding=utf-8
import datetime
import logging
import os
import os.path
import traceback

import timeout_decorator
from django.conf import settings
from django_cron import CronJobBase, Schedule

from csv_tns_subject_import_reader import TnsCsvSubjectImportReader
from importer import Importer
from web.models.constants import CRON_JOB_TIMEOUT
from ..smash_email import EmailSender

logger = logging.getLogger(__name__)


class ImporterCronJob(CronJobBase):
    RUN_AT_TIMES = getattr(settings, "IMPORT_RUN_AT", ['23:55'])
    schedule = Schedule(run_at_times=RUN_AT_TIMES)
    code = 'web.import_daily_job'  # a unique code

    @timeout_decorator.timeout(CRON_JOB_TIMEOUT)
    def do(self):
        email_title = "Daily import"
        email_recipients = getattr(settings, "DEFAULT_FROM_EMAIL", None)

        filename = getattr(settings, "DAILY_IMPORT_FILE", None)

        if filename is None:
            logger.info("Importing subjects skipped. File not defined ")
            return "import file not defined"
        logger.info("Importing subjects from file: " + filename)
        if not os.path.isfile(filename):
            EmailSender().send_email(email_title,
                                     "<h3><font color='red'>File with imported data is not available in the system: " + filename + "</font></h3>",
                                     email_recipients)
            return "import file not found"
        try:
            importer = Importer(settings.DAILY_IMPORT_FILE, TnsCsvSubjectImportReader())
            importer.execute()
            email_body = importer.get_summary()
            EmailSender().send_email(email_title,
                                     "<h3>Data was successfully imported from file: " + filename + "</h3>" + email_body,
                                     email_recipients)
            self.backup_file(filename)
            return "import is successful"

        except:
            tb = traceback.format_exc()
            EmailSender().send_email(email_title,
                                     "<h3><font color='red'>There was a problem with importing data from file: " + filename + "</font></h3><pre>" + tb + "</pre>",
                                     email_recipients)
            return "import crashed"

    def backup_file(self, filename):
        new_file = filename + "-" + datetime.datetime.now().strftime("%Y-%m-%d-%H-%M") + ".bac"
        os.rename(filename, new_file)
        return
