# coding=utf-8

import logging
import tempfile
from shutil import copyfile

from django.conf import settings
from django.test import TestCase

from web.importer import ImporterCronJob
from web.tests.functions import get_resource_path

logger = logging.getLogger(__name__)
from django.core import mail
from django_cron.models import CronJobLog


class TestCronJobImporter(TestCase):

    def tearDown(self):
        setattr(settings, "DAILY_IMPORT_FILE", None)

    def test_import_without_configuration(self):
        CronJobLog.objects.all().delete()

        job = ImporterCronJob()

        status = job.do()

        self.assertEqual("import file not defined", status)
        self.assertEqual(0, len(mail.outbox))

    def test_import(self):
        filename = get_resource_path('tns_import.csv')
        new_file, tmp = tempfile.mkstemp()
        copyfile(filename, tmp)

        setattr(settings, "DAILY_IMPORT_FILE", tmp)
        CronJobLog.objects.all().delete()

        job = ImporterCronJob()

        status = job.do()

        self.assertEqual("import is successful", status)
        self.assertEqual(1, len(mail.outbox))
